@@ -3,7 +3,7 @@ package CohortExplorer::Command::Query;
 use strict;
 use warnings;
 
-our $VERSION = 0.07;
+our $VERSION = 0.09;
 our ( $COMMAND_HISTORY_FILE, $COMMAND_HISTORY_CONFIG, $COMMAND_HISTORY );
 our @EXPORT_OK = qw($COMMAND_HISTORY);
 my $ARG_MAX = 50;
@@ -122,7 +122,7 @@ sub validate {
 
 		my ( $opr, $val ) =
 		  $opts->{cond}{$var} =~
-/^\{\'(=|\!=|>|>=|<|<=|between|not_between|like|not_like|in|not_in|regexp)\',(\[(\'[^,\`]+\',?){2,}\]|\'[^\`]+\'|undef)\}$/;
+/^\{\'(=|\!=|>|<|>=|<=|between|not_between|like|not_like|in|not_in|regexp|not_regexp)\',(\[(\'[^,\`]+\',?){2,}\]|\'[^\`]+\'|undef)\}$/;
 
 		# Validating SQL conditions
                 if ( $opr && $val ) {
@@ -155,7 +155,24 @@ sub run {
 
 	# If the result-set is not empty
 	if (@$result_set) {
-		my $dir = $1 if ( $opts->{out} =~ /^(.+)$/ );
+	        my $dir = File::Spec->catdir($1, 'CohortExplorer-'.time.$$) if ( $opts->{out} =~ /^(.+)$/ );
+
+                eval {  mkdir $dir };
+
+                if ( catch my $e ) {
+                     warn $e . "\n";
+                     $dir = $1;
+                }
+
+                else {
+                        eval { chmod 0777, $dir }; 
+                
+                        if ( catch my $e ) { 
+                             warn $e . "\n";
+                             $dir = $1;
+                        }
+                }          
+
 
 		require Text::CSV_XS;
 
@@ -173,8 +190,8 @@ sub run {
 		$self->export_data( $opts, $cache, $result_set, $dir, $csv, @args );
 
 		return {
-			headingText => 'summary statistics',
-			rows => $self->summary_stats( $opts, $cache, $result_set, $dir, $csv )
+			 headingText => 'summary statistics',
+			 rows => $self->summary_stats( $opts, $cache, $result_set, $dir, $csv )
 		  }
 		  if ( $opts->{stats} );
 	}
@@ -598,12 +615,12 @@ This class serves as the base class to search and compare command classes. The c
 Returns application option specifications as expected by L<Getopt::Long::Descriptive>
 
        ( 
-         [ 'cond|c=s%'      => 'impose conditions'                           ],
-         [ 'out|o=s'        => 'provide output directory', { required => 1 } ],
-         [ 'save-command|s' => 'save command'                                ],
-         [ 'stats|S'        => 'show summary statistics'                     ],
-         [ 'export|e=s@'    => 'export tables by name'                       ],
-         [ 'export-all|a'   => 'export all tables'                           ] 
+         [ 'cond|c=s%'      => 'impose conditions'         ],
+         [ 'out|o:s'        => 'provide output directory'  ],
+         [ 'save-command|s' => 'save command'              ],
+         [ 'stats|S'        => 'show summary statistics'   ],
+         [ 'export|e=s@'    => 'export tables by name'     ],
+         [ 'export-all|a'   => 'export all tables'         ] 
        )
 
 =head2 validate( $opts, @args )
